==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-share/app/translations/peony-share-extension_bo_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="58"/>
        <source>Advanced share</source>
        <translation>མཐོ་རིམ་མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="106"/>
        <source>Samba set user password</source>
        <translation>བེད་སྤྱོད་བྱེད་མཁན་གྱི་གསང་བ་མཉམ་སྤྱོད་བྱ་</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="106"/>
        <source>Samba password:</source>
        <translation>མཉམ་སྤྱོད་གསང་གྲངས།:</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="110"/>
        <location filename="../advanced-share-page.cpp" line="122"/>
        <source>Warning</source>
        <translation>ཐ་ཚིག་སྒྲོག་པ།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="110"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>གསང་བའི་གསང་བ་མཉམ་སྤྱོད་བྱས་ནས་ཕམ་ཉེས་བྱུང་བ་དང་བསྐྱར་དུ་ནང་འདྲེན་གནང་རོགས།!</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="118"/>
        <source>Tips</source>
        <translation>གསལ་འདེབས།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="118"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>བེད་སྤྱོད་བྱེད་མཁན་དེས་samba ཁྱོད་ཀྱིས་སྤྱོད་མཁན་བརྒྱ་ཆ་%1ལ་ཐོ་འགོད་བྱེད་དགོས་པ་དང་། ཡིག་ཆའི་དོ་དམ་ཡོ་བྱད་ཀྱི་གཡས་ངོས་སུ་ཟས་ཐོའི་ནང་དུ་samba</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="122"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>མཉམ་སྤྱོད་དང་བཀོད་སྒྲིག་ཞབས་ཞུ་ཐུན་མོང་མ་ཡིན་པ་མཉམ་སྤྱོད་བྱེད་བཞིན་པའི་མཉམ་སྤྱོད་བཀོད་སྒྲིག་བྱས་ཡོད་མེད་ངོས་འཛིན་གནང་རོགས།ཡང་ན་བསྐྱར་དུ་མཉམ་སྤྱོད་བྱེད་རོགས།!</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>User</source>
        <translation>སྤྱོད་མཁན།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Writable</source>
        <translation>བྲིས་ཆོག</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Readonly</source>
        <translation>སློབ་སྦྱོང་ཁོ་ན་བྱེད་པ</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Reject</source>
        <translation>དང་ལེན་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="358"/>
        <source>Share permission settings</source>
        <translation>མཉམ་སྤྱོད་དབང་མཚམས་བཀོད་སྒྲིག་བྱ།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="370"/>
        <source>delete</source>
        <translation>སུབ་དགོས།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="387"/>
        <source>Add</source>
        <translation>འཕར་སྣོན་བྱུང་ཡོད།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="404"/>
        <source>Save</source>
        <translation>ཉར་ཚགས་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="405"/>
        <source>Cancel</source>
        <translation>མེད་པར་བཟོ་དགོས།</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>ཡིག་ཁུག་མཉམ་སྤྱོད་བྱས་ཆོག</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="435"/>
        <source>Share folder</source>
        <translation>ཡིག་ཁུག་མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="130"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>ཡིག་ཆ་འདིའི་མིག་སྔའི་མཉམ་སྤྱོད་དཔེ་དབྱིབས་ནི་དཔེ་ཀློག་མ་དཔེ་ཙམ་ཡིན་པས། རང་འགུལ་གྱིས་མིག་སྔའི་ཡིག་ཆའི་ནང་མི་གཞན་གྱི་འབྲི་བའི་དབང་ཚད་འཕར་སྣོན་བྱེད་དགོས་སམ།?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="131"/>
        <location filename="../share-page.cpp" line="185"/>
        <source>question</source>
        <translation>དྲི་བ་འདོན་པ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="133"/>
        <location filename="../share-page.cpp" line="187"/>
        <source>Confirm adding permissions</source>
        <translation>ཁ་སྣོན་གྱི་དབང་ཚད་གཏན་འཁེལ་བྱ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="134"/>
        <location filename="../share-page.cpp" line="188"/>
        <source>Cancel</source>
        <translation>མེད་པར་བཟོ་དགོས།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <location filename="../share-page.cpp" line="113"/>
        <location filename="../share-page.cpp" line="162"/>
        <location filename="../share-page.cpp" line="171"/>
        <location filename="../share-page.cpp" line="217"/>
        <location filename="../share-page.cpp" line="227"/>
        <location filename="../share-page.cpp" line="271"/>
        <location filename="../share-page.cpp" line="300"/>
        <source>Warning</source>
        <translation>ཐ་ཚིག་སྒྲོག་པ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>མཉམ་སྤྱོད་མིང་གྲགས་སུ་བརྒྱ་ཆ%1，འགོ་རྩོམ་པའམ་- ཡང་ན་སྟོང་པར་འགོ་འཛུགས་པའམ་ཡང་ན་སྟོང་ཆ་མཇུག་སྒྲིལ་བ་བཅས་བྱེད་མི་རུང་།</translation>
    </message>
    <message>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation type="vanished">ཡིག་ཆ་འདིའི་ནང་དུ་མིག་སྔར་མིང་མི་འགོད་པའི་འཚམས་འདྲི་བྱས་ཡོད་པས། རང་འགུལ་གྱིས་མིག་སྔའི་ཡིག་ཆ་དང་མེས་པོའི་དཀར་ཆག་ཁ་སྣོན་བྱེད་དགོས་པའི་མི་གཞན་དག་གི་ལག་བསྟར་དབང་མཚམས་འཇོག་དགོས་སམ།?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="113"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="184"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically add executable permissions for the current file and all other members of the parent directory?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="271"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>མཉམ་སྤྱོད་དང་བཀོད་སྒྲིག་ཞབས་ཞུ་ཐུན་མོང་མ་ཡིན་པ་མཉམ་སྤྱོད་བྱེད་བཞིན་པའི་མཉམ་སྤྱོད་བཀོད་སྒྲིག་བྱས་ཡོད་མེད་ངོས་འཛིན་གནང་རོགས།ཡང་ན་བསྐྱར་དུ་མཉམ་སྤྱོད་བྱེད་རོགས།!</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="280"/>
        <source>Samba set user password</source>
        <translation>བེད་སྤྱོད་བྱེད་མཁན་གྱི་གསང་བ་མཉམ་སྤྱོད་བྱ་</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="280"/>
        <source>Samba password:</source>
        <translation>མཉམ་སྤྱོད་གསང་གྲངས།:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="300"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>གསང་བའི་གསང་བ་མཉམ་སྤྱོད་བྱས་ནས་ཕམ་ཉེས་བྱུང་བ་དང་བསྐྱར་དུ་ནང་འདྲེན་གནང་རོགས།!</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="402"/>
        <source>usershare</source>
        <translation>གོ་སྐབས་འདི་མཉམ་སྤྱོད་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="406"/>
        <location filename="../share-page.cpp" line="451"/>
        <source>share this folder</source>
        <translation>ཡིག་ཁུག་འདི་མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="406"/>
        <location filename="../share-page.cpp" line="458"/>
        <source>don`t share this folder</source>
        <translation>ཡིག་ཁུག་འདི་མཉམ་སྤྱོད་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="486"/>
        <source>Share name:</source>
        <translation>མཉམ་སྤྱོད་ཀྱི་མིང་།:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="491"/>
        <source>Allow others to create and delete files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="vanished">ཀློག་ཙམ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="494"/>
        <source>Allow Anonymous</source>
        <translation>ཡུལ་སྐོར་བར་ལྟ་སྤྱོད་བྱས་ཆོག</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="503"/>
        <source>Advanced Sharing</source>
        <translation>མཐོ་རིམ་མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="487"/>
        <source>Comment:</source>
        <translation>མཆན་འགྲེལ།:</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-share/app/translations/peony-share-extension_bo_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>ཡིག་ཁུག་མཉམ་སྤྱོད་བྱེད་ཆོག</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="169"/>
        <source>Share folder</source>
        <translation>ཡིག་ཁུག་མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="140"/>
        <source>usershare</source>
        <translation>གློག་ཀླད་འདིའི་མཉམ་སྤྱོད་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <location filename="../share-page.cpp" line="187"/>
        <source>share this folder</source>
        <translation>ཡིག་ཁུག་འདི་མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <location filename="../share-page.cpp" line="194"/>
        <source>don`t share this folder</source>
        <translation>ཡིག་ཁུག་འདི་མཉམ་སྤྱོད་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="220"/>
        <source>Share name:</source>
        <translation>མཉམ་སྤྱོད་ཀྱི་མིང་།:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="225"/>
        <source>Read Only</source>
        <translation>ཀློག་ཙམ།</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="228"/>
        <source>Allow Anonymous</source>
        <translation>ཡུལ་སྐོར་བར་ལྟ་སྤྱོད་བྱས་ཆོག</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="221"/>
        <source>Comment:</source>
        <translation>མཆན་འགྲེལ།:</translation>
    </message>
</context>
</TS>
